spoon.messaging

Package spoon :: Package messaging |
[hide private]
[frames] | no frames]

# Package messaging

source code

Submodules | [hide private]
spoon.messaging.decorators spoon.messaging.messagingcore

Classes | [hide private]
`` | receive The receive decorator can be used to decorate functions and static methods (NOT methods of class instances) that should receive messages of a given type.
`` | handleMsg The receive decorator can be used to decorate functions and static methods (NOT methods of class instances) that should receive messages of a given type.
`` | Messaging This is the main messaging class that implements the basic functionality for Spoon.
`` | SingletonMessaging For convinience this is a singleton version of the Messaging system.

Functions | [hide private]
`` | send(dst, messageStr, obj) Shortcut for calling send on the SingletonMessaging class.
`` | x(dst, messageStr, obj) Shortcut for calling send on the SingletonMessaging class.

Variables | [hide private]
`` | __module__ = `'spoon'`

Function Details | [hide private]

### send(dst, messageStr, obj) | source code
Shortcut for calling send on the SingletonMessaging class. Parameters: `dst` - Destination node id `messageStr` - A string describing the message type. `obj` - Some object attached the net message.

### x(dst, messageStr, obj) | source code
Shortcut for calling send on the SingletonMessaging class. Parameters: `dst` - Destination node id `messageStr` - A string describing the message type. `obj` - Some object attached the net message.

Variables Details | [hide private]

    ### __module__ None Value:
        'spoon'